@@ -2,7 +2,7 @@
  * ====                   FRACTAL GRAPHICS GENERATOR                     ====
  * ==========================================================================
  *
- * Copyright (C) 2003-2018 by Thomas Dreibholz
+ * Copyright (C) 2003-2019 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,10 +23,6 @@
 #ifndef FRACTALGENERATORDOC_H
 #define FRACTALGENERATORDOC_H
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include <QObject>
 #include <QString>
 #include <QList>
@@ -57,7 +53,7 @@ class FractalGeneratorDoc : public QObject
    bool saveModified();
    void closeDocument();
 
-   signals:
+   Q_SIGNALS:
    void updateFileName(const QString& fileName);
 
    private:
