@@ -2,7 +2,7 @@
  * ====                   FRACTAL GRAPHICS GENERATOR                     ====
  * ==========================================================================
  *
- * Copyright (C) 2003-2018 by Thomas Dreibholz
+ * Copyright (C) 2003-2019 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ class SimpleRGB : public ColorSchemeInterface  {
              const char* name       = "Simple RGB");
    ~SimpleRGB();
 
-   virtual unsigned int getColor(const unsigned int value);
+   virtual unsigned int getColor(const unsigned int value) override;
 
    private:
    static unsigned int rgbFromWaveLength(const double wave);
