@@ -1,9 +1,8 @@
-/* $Id$
- * ==========================================================================
+/* ==========================================================================
  * ====                   FRACTAL GRAPHICS GENERATOR                     ====
  * ==========================================================================
  *
- * Copyright (C) 2003-2017 by Thomas Dreibholz
+ * Copyright (C) 2003-2019 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,9 +34,9 @@ class UIntConfigEntry : public ConfigEntry  {
    UIntConfigEntry(unsigned int* valuePtr, const char* name);
    ~UIntConfigEntry();
 
-   virtual QString getName() const;
-   virtual QString getValueAsString() const;
-   virtual void setValueFromString(const QString& valueString);
+   virtual QString getName() const override;
+   virtual QString getValueAsString() const override;
+   virtual void setValueFromString(const QString& valueString) override;
 
    private:
    QString       EntryName;
